@@ -14,7 +14,13 @@ Changelog
 0.0.5:add automate package management
 
 0.0.6:add automate package management success
+
+0.0.7:add automate release test
+
+0.0.8:add automate release test again
+
+0.0.9:add automate success
 """
 
-__version__ = "0.0.6"
+__version__ = "0.0.9"
 __author__ = "Albert King"
